pub fn expect_char(ch: char, text0: &str) -> ParseResult<'_, ()>Expand description
Consume next character and require that it be ch.
pub fn expect_char(ch: char, text0: &str) -> ParseResult<'_, ()>Consume next character and require that it be ch.