pub fn identifier(text: &str) -> ParseResult<'_, String>Expand description
Extracts a maximal identifier from the start of text, following the usual rules.
pub fn identifier(text: &str) -> ParseResult<'_, String>Extracts a maximal identifier from the start of text, following the usual rules.