pub fn number<T>(text0: &str) -> ParseResult<'_, T>Expand description
Extract a number from the input, erroring if the input does not start with a number.
pub fn number<T>(text0: &str) -> ParseResult<'_, T>Extract a number from the input, erroring if the input does not start with a number.